@@ -104,7 +104,7 @@ def set_aml_context() -> None:
     global _AML_RUN
     from azureml.core.run import Run
 
-    _AML_RUN = Run.get_context(allow_offline=False)
+    _AML_RUN = Run.get_context()
 
 
 def get_aml_context():
@@ -140,8 +140,12 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
     https://github.com/python/cpython/blob/3.8/Lib/logging/__init__.py
     """
 
-    def __init__(self, name: str, use_aml_metrics: bool = False):
+    def __init__(self, name: str, use_aml_metrics: bool = False, handlers=None):
         super().__init__(name)  # type: ignore
+
+        if handlers:
+            self.handlers = handlers
+
         self.start_time = datetime.now()
         self.metric_count = 1
         # number of iterable items that are logged
@@ -154,8 +158,7 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
                 try:
                     set_aml_context()
                     self.info(
-                        "AML Metrics:"
-                        + f"{get_aml_context().get_status()}",  # type: ignore
+                        "AML Metrics:" + f"{get_aml_context().id}",  # type: ignore
                         category=DataCategory.PUBLIC,
                     )
                 except Exception:
@@ -349,11 +352,10 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
                     run.log(name=name, value=value, description=description, step=step)
                 else:
                     run.log(name=name, value=value, description=description)
-            else:
-                self.info(
-                    f"NumbericMetric  | {name}:{step} | {value}",
-                    category=category,
-                )
+            self.info(
+                f"NumbericMetric  | {name}:{step} | {value}",
+                category=category,
+            )
 
             return
 
@@ -388,25 +390,24 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
             if type_set == list:
                 if run is not None and category == DataCategory.PUBLIC:
                     run.log_table(name, value, description)
-                else:
-                    # log the matrix manually
-                    col_names = " | ".join(
-                        [f"{('' if col is None else col):15}" for col in value.keys()]
-                    )
-                    header = f"TableMetric     | Index | {col_names} |"
-                    self.info(f"TableMetric     | {name}", category=category)
-                    self.info(header, category=category)
-                    self.info("-" * len(header), category=category)
+                # log the matrix manually
+                col_names = " | ".join(
+                    [f"{('' if col is None else col):15}" for col in value.keys()]
+                )
+                header = f"TableMetric     | Index | {col_names} |"
+                self.info(f"TableMetric     | {name}", category=category)
+                self.info(header, category=category)
+                self.info("-" * len(header), category=category)
 
-                    # generate the rows
-                    max_rows = max([len(value[col]) for col in value])
-                    for i in range(max_rows):
-                        row_str = f"TableMetric     | {i:05}"
-                        for key in value:
-                            col = value[key]
-                            col = col[i] if i < len(col) and col[i] else ""
-                            row_str += f" | {str(col):15}"
-                        self.info(row_str, category=category)
+                # generate the rows
+                max_rows = max([len(value[col]) for col in value])
+                for i in range(max_rows):
+                    row_str = f"TableMetric     | {i:05}"
+                    for key in value:
+                        col = value[key]
+                        col = col[i] if i < len(col) and col[i] else ""
+                        row_str += f" | {str(col):15}"
+                    self.info(row_str, category=category)
             elif type_set in [int, float]:
                 for key, val in value.items():
                     key = name + "/" + key
@@ -443,8 +444,7 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
             # log data to run context
             if run is not None and category == DataCategory.PUBLIC:
                 run.log_list(name=name, value=value, description=description)
-            else:
-                self.info(f"ListMetric      | {name} | {value}", category=category)
+            self.info(f"ListMetric      | {name} | {value}", category=category)
 
             return
 
@@ -1029,10 +1029,9 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
         # log the data
         if category == DataCategory.PUBLIC and run is not None:
             run.log_row(name=name, description=description, **kwargs)
-        else:
-            row_str = f"RowMetric      | {name} | "
-            row_str += " | ".join([f"{r}:{c}" for r, c in kwargs.items()])
-            self.info(row_str, category=category)
+        row_str = f"RowMetric      | {name} | "
+        row_str += " | ".join([f"{r}:{c}" for r, c in kwargs.items()])
+        self.info(row_str, category=category)
 
     def metric_table(
         self, name, value, description=None, category=DataCategory.PRIVATE
@@ -1120,10 +1119,9 @@ def enable_compliant_logging(
     if "force" not in kwargs and sys.version_info >= (3, 8):
         kwargs["force"] = True
 
-    old_root = logging.root
-
-    root = CompliantLogger(logging.root.name, use_aml_metrics)
-    root.handlers = old_root.handlers
+    root = CompliantLogger(
+        logging.root.name, use_aml_metrics, handlers=logging.root.handlers
+    )
 
     logging.root = root
     logging.Logger.root = root  # type: ignore
