@@ -29,7 +29,9 @@ def get_repo_info():
             "git": repo.remotes.origin.url,
             "branch": branch.name,
             "commit": head.commit.hexsha,
-            "last_known_author": head.commit.author.name,
+            "last_known_author": head.commit.author.name.encode(
+                "ascii", "ignore"
+            ).decode(),
         }
     except:
         return {"git": "n/a"}
